@@ -705,6 +705,11 @@ class DataFrame(metaclass=DataFrameMeta):
                 df = df.filter(pl_expr)
             # Do the projection
             if len(projections) > 0:
+                polars_cols_set = set(df.columns)
+                missing_cols = [c for c in projections if c not in polars_cols_set]
+                if len(missing_cols) > 0:
+                    raise KeyError(f"Attempt to select missing columns {missing_cols}")
+
                 df = df.select(projections)
             return DataFrame(df, pydantic_model=self)
         else:
