@@ -27,6 +27,7 @@ import pyarrow
 from pydantic import BaseModel
 from typing_extensions import ParamSpec
 
+from chalk._autosql.autosql import query_as_feature_formatted
 from chalk.features.dataframe import DataFrame
 from chalk.features.feature_field import Feature
 from chalk.features.feature_set import Features
@@ -850,6 +851,12 @@ class StreamResolver(Resolver[P, T]):
         self.window_periods_seconds = next(iter(fqn_to_windows.values()), ())
         # Mapping of window (in secs) to mapping of (original feature, windowed pseudofeature)
         self.windowed_pseudofeatures: Dict[int, Dict[Feature, Feature]] = {}
+        self.window_index = None
+        for i, w in enumerate(signature.params):
+            if isinstance(w, StreamResolverParamMessageWindow):
+                self.window_index = i
+                break
+
         for window_period in self.window_periods_seconds:
             self.windowed_pseudofeatures[window_period] = {}
             for o in _flatten_features(self.output):
@@ -859,11 +866,19 @@ class StreamResolver(Resolver[P, T]):
                     self.windowed_pseudofeatures[window_period][o] = windowed_feature
 
     @property
-    def output_features(self):
+    def output_features(self) -> Sequence[Feature]:
         return _flatten_features(self.output)
 
     def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T:
-        return self.fn(*args, **kwargs)
+        raw_result = self.fn(*args, **kwargs)
+        if self.window_index is not None and isinstance(raw_result, str) and str(args[self.window_index]) in raw_result:
+            raw_result = query_as_feature_formatted(
+                formatted_query=raw_result,
+                expected_features=[s.name for s in self.output_features],
+                table=args[self.window_index],
+            )
+
+        return raw_result
 
     def __repr__(self):
         return f"StreamResolver(name={self.fqn})"
@@ -918,6 +933,9 @@ def _parse_stream_resolver_param(
     if is_windowed_resolver and isclass(annotation) and issubclass(annotation, (pyarrow.Table, polars.DataFrame)):
         return StreamResolverParamMessageWindow(name=param.name, typ=annotation)
 
+    if is_windowed_resolver and isclass(annotation) and issubclass(annotation, DataFrame):
+        return StreamResolverParamMessageWindow(name=param.name, typ=annotation)
+
     raise ValueError(
         (
             f"Stream resolver parameter '{param.name}' of resolver '{resolver_fqn_for_errors}' is not recognized. "
