@@ -42,15 +42,26 @@ def import_all_python_files() -> List[FailedImport]:
     return import_all_python_files_from_dir(project_root=project_root)
 
 
-def import_all_python_files_from_dir(project_root: Path) -> List[FailedImport]:
-    gitignore_path = project_root / ".gitignore"
-    chalk_ignore_path = project_root / ".chalkignore"
-    matching_functions = []
-    if gitignore_path.exists():
-        matching_functions.append(parse_gitignore(str(gitignore_path)))
+def _search_recursively_for_file(base: Path, filename: str) -> List[Path]:
+    ans = []
+    assert base.is_dir()
+    while True:
+        filepath = base / filename
+        if filepath.exists():
+            ans.append(filepath)
+        parent = base.parent
+        if parent == base:
+            return ans
+        base = parent
 
-    if chalk_ignore_path.exists():
-        matching_functions.append(parse_gitignore(str(chalk_ignore_path)))
+
+def import_all_python_files_from_dir(project_root: Path) -> List[FailedImport]:
+    project_root = project_root.absolute()
+    matching_functions = []
+    matching_functions.extend(parse_gitignore(str(x)) for x in _search_recursively_for_file(project_root, ".gitignore"))
+    matching_functions.extend(
+        parse_gitignore(str(x)) for x in _search_recursively_for_file(project_root, ".chalkignore")
+    )
 
     is_relevant = lambda x: all((not match(x) for match in matching_functions))
 
