@@ -5,6 +5,7 @@ import pyarrow
 from pydantic import BaseModel
 from typing_extensions import TypeAlias
 
+from chalk.features import DataFrame
 from chalk.utils import AnyDataclass
 
 
@@ -23,6 +24,7 @@ StreamResolverWindowType: TypeAlias = Union[
     Type[AnyDataclass],
     Type[pyarrow.Table],
     Type[polars.DataFrame],
+    Type[DataFrame],
     Any,  # The annotation value is likely going to be a GenericAlias, which messes with pydantic's validation
 ]
 
