@@ -1,5 +1,7 @@
+import re
 from datetime import timedelta
-from typing import Literal, Optional, Union
+from re import Pattern
+from typing import Literal, Mapping, Optional, Tuple, Union
 
 # Duration is used to describe time periods in
 # natural langauge. To specify using natural
@@ -49,3 +51,37 @@ def timedelta_to_duration(t: timedelta) -> Duration:
             s += " "
         s += f"{t.seconds}s"
     return s
+
+
+_kwarg_to_regex: Mapping[str, Pattern] = {
+    k: re.compile(f"(([0-9]+?){v})")
+    for k, v in dict(
+        weeks="w",
+        days="d",
+        hours="h",
+        minutes="m",
+        seconds="s",
+    ).items()
+}
+
+
+def parse_chalk_duration(s: str) -> timedelta:
+    def parse(regex: Pattern) -> Tuple[int, str]:
+        matched = regex.search(s)
+        if matched is None:
+            return 0, ""
+
+        return int(matched.groups()[1]), matched.groups()[0]
+
+    parsed_values = {k: parse(unit) for k, unit in _kwarg_to_regex.items()}
+
+    # Check for remaining unparsed input
+    remainder = s
+    for v in parsed_values.values():
+        remainder = remainder.replace(v[1], "", 1)
+    remainder = remainder.strip()
+
+    if remainder != "":
+        raise ValueError(f"Unparsed portion of duration: '{remainder}' for input: '{s}'")
+
+    return timedelta(**{k: v[0] for k, v in parsed_values.items()})
