@@ -18,3 +18,11 @@ def removeprefix(text: str, prefix: str):
 
 def comma_whitespace_split(value: str):
     return re.split(r"\s*,\s*", value)
+
+
+def normalize_string_for_matching(name: str) -> str:
+    """
+    1. Case insensitive
+    2. Strip non-alphanumeric, so e.g. `first_name` matches `firstname`
+    """
+    return re.sub("[^0-9a-z]", "", name.lower())
