@@ -8,6 +8,7 @@ import pandas as pd
 import polars as pl
 import polars.testing
 import pytest
+from pydantic import BaseModel
 
 try:
     import zoneinfo
@@ -62,7 +63,29 @@ class Topping:
     price: ToppingPrice = has_one(lambda: ToppingPrice.topping_id == Topping.id)
 
 
+class Thing(BaseModel):
+    id: str
+    wow: str
+
+
 class TestDF:
+    def test_dataframe_with_pydantic(self):
+        df_type = DataFrame[Thing]
+        assert df_type.columns == ()
+        assert df_type.__pydantic_model__ == Thing
+        x = DataFrame(
+            polars.DataFrame(
+                {
+                    "id": ["hello", "there"],
+                    "wow": ["hello", "there"],
+                }
+            ),
+            pydantic_model=Thing,
+        )
+        assert x["wow"].max() == "there"
+        x.to_polars()
+        x.to_pandas()
+
     def test_indexing(self):
         f = DataFrame({Taco.id: [1, 2, 3], Taco.price: [5, 6, 7]})
         polars.testing.assert_frame_equal(
